from pathlib import Path
from unittest.mock import patch, call
from django.core.management import call_command
from django.core.management.base import CommandError
from arkindex.project.tests import FixtureTestCase

ACT_SAMPLES = Path(__file__).resolve().parent.parent / 'act_samples'


@patch('arkindex.himanis.management.commands.import_acts.ActsImporter')
class TestImportActsCommand(FixtureTestCase):

    def test_run(self, importer_mock):
        call_command(
            'import_acts',
            ACT_SAMPLES,
            corpus=self.corpus,
        )
        self.assertEqual(importer_mock.call_count, 1)
        self.assertEqual(importer_mock.call_args, call(
            ACT_SAMPLES / 'volume 2.csv',
            self.corpus,
            self.corpus.types.get(slug='volume'),
            self.corpus.types.get(slug='act'),
            self.corpus.types.get(slug='surface'),
        ))
        self.assertEqual(importer_mock().run.call_count, 1)

    def test_path_not_found(self, importer_mock):
        with self.assertRaisesRegex(CommandError, 'does not exist'):
            call_command(
                'import_acts',
                Path('/nowhere'),
                corpus=self.corpus,
            )

    def test_wrong_folder_type(self, importer_mock):
        with self.assertRaises(
                CommandError,
                msg="Folder type with slug 'burrito' in corpus Unit Tests does not exist"):
            call_command(
                'import_acts',
                ACT_SAMPLES,
                corpus=self.corpus,
                folder_slug='burrito',
            )

    def test_wrong_act_type(self, importer_mock):
        with self.assertRaises(
                CommandError,
                msg="Act type with slug 'act' in corpus Unit Tests does not exist"):
            call_command(
                'import_acts',
                ACT_SAMPLES,
                corpus=self.corpus,
                act_slug='burrito',
            )

    def test_wrong_surface_type(self, importer_mock):
        with self.assertRaises(
                CommandError,
                msg="Surface type with slug 'burrito' in corpus Unit Tests does not exist"):
            call_command(
                'import_acts',
                ACT_SAMPLES,
                corpus=self.corpus,
                surface_slug='burrito',
            )
