from arkindex.project.tests import FixtureTestCase
from arkindex.project.aws import S3FileStatus
from django.core.management import call_command
from django.core.management.base import CommandError
from unittest.mock import patch


class TestCheckImages(FixtureTestCase):

    @classmethod
    def setUpTestData(cls):
        super().setUpTestData()
        cls.p1 = cls.corpus.elements.get(name='Volume 1, page 1r')
        cls.p2 = cls.corpus.elements.get(name='Volume 1, page 1v')

        # Set two images to Checked
        cls.imgsrv.images.filter(path='img5').update(status=S3FileStatus.Checked)
        cls.imgsrv.images.filter(path='img6').update(status=S3FileStatus.Checked)

        # Create an image linked to zero elements
        cls.imgsrv.images.create(path='am-outside')

    @patch('arkindex.images.management.commands.check_images.Image.perform_check')
    def test_nothing(self, check_mock):
        call_command(
            'check_images',
        )
        self.assertEqual(check_mock.call_count, 5)

    @patch('arkindex.images.management.commands.check_images.Image.perform_check')
    def test_corpus(self, check_mock):
        call_command(
            'check_images',
            corpus=self.corpus,
        )
        self.assertEqual(check_mock.call_count, 4)

    @patch('arkindex.images.management.commands.check_images.Image.perform_check')
    def test_element(self, check_mock):
        call_command(
            'check_images',
            element=[self.p1, self.p2],
        )
        self.assertEqual(check_mock.call_count, 2)

    def test_corpus_xor_element(self):
        with self.assertRaises(CommandError):
            call_command(
                'check_images',
                corpus=self.corpus,
                element=[self.p1, ],
            )

    @patch('arkindex.images.management.commands.check_images.Image.perform_check')
    def test_force(self, check_mock):
        call_command(
            'check_images',
            force=True,
        )
        self.assertEqual(check_mock.call_count, 7)
