from arkindex.project.tests import FixtureTestCase
from unittest.mock import patch, call
from django.test import override_settings


@override_settings(LOCAL_IMAGESERVER_ID=999, IIIF_DOWNLOAD_TIMEOUT=(13, 37))
class TestThumbnail(FixtureTestCase):

    @classmethod
    def setUpClass(cls):
        super().setUpClass()
        cls.s3_mock = patch('arkindex.project.aws.s3').start()

    @classmethod
    def setUpTestData(cls):
        super().setUpTestData()
        cls.vol1 = cls.corpus.elements.get(name='Volume 1')

    def tearDown(self):
        super().tearDown()
        self.s3_mock.reset_mock()
        try:
            # Remove the cached S3 object to force a reinstanciation
            del self.vol1.thumbnail.s3_object
        except AttributeError:  # Sometimes, it isn't already cached
            pass

    def test_name(self):
        self.assertEqual(self.vol1.thumbnail.name, str(self.vol1.id.hex) + '.jpg')

    def test_s3_object(self):
        thumbnail = self.vol1.thumbnail
        thumbnail.s3_bucket = 'derp'
        # Test twice to ensure s3_object is only created once
        self.assertEqual(thumbnail.s3_object, self.s3_mock.Object.return_value)
        self.assertEqual(thumbnail.s3_object, self.s3_mock.Object.return_value)
        self.assertEqual(self.s3_mock.Object.call_count, 1)
        self.assertEqual(self.s3_mock.Object.call_args, call('derp', self.vol1.thumbnail.name))

    def test_url(self):
        self.s3_mock.meta.client.generate_presigned_url.return_value = 'http://nowhere'
        self.s3_mock.Object.return_value.bucket_name = 'derp'
        self.s3_mock.Object.return_value.key = 'meme.jpg'
        thumbnail = self.vol1.thumbnail
        thumbnail.s3_bucket = 'derp'
        self.assertEqual(thumbnail.s3_url, 'http://nowhere')
        self.assertEqual(self.s3_mock.Object.call_count, 1)
        self.assertEqual(self.s3_mock.meta.client.generate_presigned_url.call_count, 1)
        self.assertEqual(
            self.s3_mock.meta.client.generate_presigned_url.call_args,
            call('get_object', Params={'Bucket': 'derp', 'Key': 'meme.jpg'}),
        )
