# Generated by Django 2.2.9 on 2020-01-17 15:39

import arkindex.users.models
from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion
import enumfields.fields
import uuid


def create_internal_group(apps, schema_editor):
    """
    Create the internal group, used for permission checking

    In the event of a migrations reset, this should be kept to make deployments simpler.
    """
    Group = apps.get_model('auth', 'Group')
    Group.objects.create(id=settings.INTERNAL_GROUP_ID, name='Internal')


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('auth', '0011_update_proxy_permissions'),
        ('documents', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='User',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('password', models.CharField(max_length=128, verbose_name='password')),
                ('last_login', models.DateTimeField(blank=True, null=True, verbose_name='last login')),
                ('email', models.EmailField(max_length=255, unique=True, verbose_name='email address')),
                ('is_active', models.BooleanField(default=True)),
                ('is_admin', models.BooleanField(default=False)),
                ('verified_email', models.BooleanField(default=False)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='OAuthCredentials',
            fields=[
                ('id', models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ('provider_name', models.CharField(choices=[('GitLabOAuthProvider', 'GitLab')], max_length=50)),
                ('provider_url', models.URLField()),
                ('status', enumfields.fields.EnumField(default='created', enum=arkindex.users.models.OAuthStatus, max_length=10)),
                ('token', models.CharField(blank=True, max_length=64, null=True)),
                ('refresh_token', models.CharField(blank=True, max_length=64, null=True)),
                ('expiry', models.DateTimeField(blank=True, null=True)),
                ('account_name', models.CharField(blank=True, max_length=100, null=True)),
                ('user', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='credentials', to=settings.AUTH_USER_MODEL)),
            ],
        ),
        migrations.CreateModel(
            name='CorpusRight',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('can_write', models.BooleanField(default=False)),
                ('can_admin', models.BooleanField(default=False)),
                ('corpus', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='corpus_right', to='documents.Corpus')),
                ('user', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='corpus_right', to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'unique_together': {('user', 'corpus')},
            },
        ),
        migrations.AddField(
            model_name='user',
            name='corpus',
            field=models.ManyToManyField(through='users.CorpusRight', to='documents.Corpus'),
        ),
        migrations.AddField(
            model_name='user',
            name='groups',
            field=models.ManyToManyField(blank=True, related_name='users', to='auth.Group'),
        ),
        migrations.RunPython(
            create_internal_group,
            reverse_code=migrations.RunPython.noop,
        )
    ]
